@@ -2,9 +2,9 @@ from __future__ import annotations
 
 import dataclasses
 from pathlib import Path
-from typing import Any
+from typing import Any, List
 
-from kraken.core import Project, Property, TaskResult
+from kraken.core import Project, Property
 
 from .base_task import EnvironmentAwareDispatchTask
 
@@ -12,9 +12,11 @@ from .base_task import EnvironmentAwareDispatchTask
 class IsortTask(EnvironmentAwareDispatchTask):
     check_only: Property[bool] = Property.config(default=False)
     config_file: Property[Path]
+    additional_files: Property[List[Path]] = Property.config(default_factory=list)
 
-    def get_execute_command(self) -> list[str] | TaskResult:
+    def get_execute_command(self) -> list[str]:
         command = ["isort", "src/"] + self.settings.get_tests_directory_as_args()
+        command += [str(p) for p in self.additional_files.get()]
         if self.check_only.get():
             command += ["--check-only"]
         if self.config_file.is_filled():
